"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const playlist_1 = require("./playlist");
const stream_info_1 = require("./stream-info");
const audio_track_1 = require("./audio-track");
var RenditionType;
(function (RenditionType) {
    RenditionType[RenditionType["video"] = 0] = "video";
    RenditionType[RenditionType["audio"] = 1] = "audio";
    RenditionType[RenditionType["iframe"] = 2] = "iframe";
})(RenditionType = exports.RenditionType || (exports.RenditionType = {}));
class Rendition {
    constructor(playlist, variant) {
        this._variant = variant;
        this._streamInfo = new stream_info_1.StreamInfo(playlist, variant);
        this._playlist = playlist;
    }
    get variant() {
        return this._variant;
    }
    get playlist() {
        return this._playlist;
    }
    get streamInfo() {
        return this._streamInfo;
    }
    get audioTracks() {
        return this._streamInfo.getTracks();
    }
    get type() {
        if (this.variant.isIFrameOnly) {
            return RenditionType.iframe;
        }
        else if (this._streamInfo.hasAudio() && !this._streamInfo.hasVideo()) {
            return RenditionType.audio;
        }
        else {
            return RenditionType.video;
        }
    }
    get height() {
        var _a;
        return ((_a = this.variant.resolution) === null || _a === void 0 ? void 0 : _a.height) || 0;
    }
    get frameRate() {
        var _a;
        return ((_a = this.variant) === null || _a === void 0 ? void 0 : _a.frameRate) || 0;
    }
    get bandwidth() {
        return this.variant.bandwidth;
    }
    get averageBandwidth() {
        var _a;
        return ((_a = this.variant) === null || _a === void 0 ? void 0 : _a.averageBandwidth) || 0;
    }
    get defaultAudioTrack() {
        var _a;
        if (((_a = this._variant.audio) === null || _a === void 0 ? void 0 : _a.length) === 0) {
            return null;
        }
        const defaultRendition = this._variant.audio.filter((rendition) => {
            return rendition.isDefault;
        });
        return new audio_track_1.AudioTrack(this._playlist, defaultRendition.length > 0 ? defaultRendition[0] : this._variant.audio[0]);
    }
    get uri() {
        return this.variant.uri;
    }
    get absoluteUri() {
        return playlist_1.Playlist.buildUrl(this._playlist.getBaseUrl() + this.variant.uri, this._playlist.getQueryStringParams());
    }
    isResolutionBetween(range) {
        return (this.height == 0 || (this.height >= range[0] && this.height <= range[1]));
    }
    isFrameRateBetween(range) {
        return (this.frameRate == 0 ||
            (this.frameRate >= range[0] && this.frameRate <= range[1]));
    }
    isBandwidthBetween(range) {
        const bandwidth = this.bandwidth || this.averageBandwidth;
        return (typeof bandwidth == "undefined" ||
            (bandwidth >= range[0] && bandwidth <= range[1]));
    }
    toString() {
        let out = "";
        out += this._streamInfo.toString();
        if (this.variant.isIFrameOnly) {
            return out;
        }
        if (this._playlist.hasDynamicChunklists()) {
            const props = JSON.parse(JSON.stringify(this._playlist.getDynamicChunklistProperties()));
            props.uri = this.variant.uri;
            props.baseUrl = this._playlist.getBaseUrl();
            out +=
                playlist_1.Playlist.buildUrl(this._playlist.getDynamicChunklistEndpoint(), props) +
                    "\n";
        }
        else {
            out += this.absoluteUri + "\n";
        }
        return out;
    }
}
exports.Rendition = Rendition;
