"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const playlist_1 = require("./playlist");
class MediaTrack {
    constructor(playlist, rendition) {
        this.rendition = rendition;
        this.playlist = playlist;
    }
    getType() {
        return this.rendition.type;
    }
    isAudio() {
        return this.rendition.type === 'AUDIO';
    }
    getUniqueKey() {
        return this.rendition.groupId + ' ' +
            this.rendition.type + ' ' +
            this.rendition.name;
    }
    toString() {
        let out = '';
        let properties = [];
        if (this.rendition.groupId) {
            properties.push(['GROUP-ID', this.rendition.groupId]);
        }
        if (this.rendition.name) {
            properties.push(['NAME', this.rendition.name]);
        }
        if (this.rendition.language) {
            properties.push(['LANGUAGE', '"' + this.rendition.language + '"']);
        }
        if (this.rendition.assocLanguage) {
            properties.push(['ASSOC-LANGUAGE', '"' + this.rendition.assocLanguage + '"']);
        }
        if (typeof this.rendition.isDefault != 'undefined') {
            properties.push(['DEFAULT', this.rendition.isDefault ? 'YES' : 'NO']);
        }
        if (typeof this.rendition.forced != 'undefined') {
            properties.push(['FORCED', this.rendition.forced ? 'YES' : 'NO']);
        }
        if (typeof this.rendition.autoselect != 'undefined') {
            properties.push(['AUTOSELECT', this.rendition.autoselect ? 'YES' : 'NO']);
        }
        if (this.rendition.characteristics) {
            properties.push(['CHARACTERISTICS', '"' + this.rendition.characteristics + '"']);
        }
        if (this.rendition.channels) {
            properties.push(['CHANNELS', '"' + this.rendition.channels + '"']);
        }
        if (this.rendition.instreamId) {
            properties.push(['INSTREAM-ID', '"' + this.rendition.instreamId + '"']);
        }
        if (this.rendition.uri) {
            properties.push([
                'URI',
                playlist_1.Playlist.buildUrl(this.playlist.getBaseUrl() + this.rendition.uri, this.playlist.getQueryStringParams())
            ]);
        }
        out += "#EXT-X-MEDIA:TYPE=" + this.rendition.type + ",";
        for (let i = 0; i < properties.length; i++) {
            if (i > 0) {
                out += ',';
            }
            out += properties[i].join('=');
        }
        out += "\n";
        return out;
    }
}
exports.MediaTrack = MediaTrack;
