"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const playlist_1 = require("./playlist");
const stream_info_1 = require("./stream-info");
var RenditionType;
(function (RenditionType) {
    RenditionType[RenditionType["video"] = 0] = "video";
    RenditionType[RenditionType["audio"] = 1] = "audio";
    RenditionType[RenditionType["iframe"] = 2] = "iframe";
})(RenditionType = exports.RenditionType || (exports.RenditionType = {}));
class Rendition {
    constructor(playlist, variant) {
        this.variant = variant;
        this.streamInfo = new stream_info_1.StreamInfo(playlist, variant);
        this.playlist = playlist;
    }
    getTracks() {
        return this.streamInfo.getTracks();
    }
    getType() {
        if (this.variant.isIFrameOnly) {
            return RenditionType.iframe;
        }
        else if (this.streamInfo.hasAudio() && !this.streamInfo.hasVideo()) {
            return RenditionType.audio;
        }
        else {
            return RenditionType.video;
        }
    }
    getHeight() {
        var _a;
        return ((_a = this.variant.resolution) === null || _a === void 0 ? void 0 : _a.height) || 0;
    }
    getFrameRate() {
        var _a;
        return ((_a = this.variant) === null || _a === void 0 ? void 0 : _a.frameRate) || 0;
    }
    getBandwidth() {
        return this.variant.bandwidth;
    }
    getAverageBandwidth() {
        var _a;
        return ((_a = this.variant) === null || _a === void 0 ? void 0 : _a.averageBandwidth) || 0;
    }
    getUri() {
        return this.variant.uri;
    }
    isResolutionBetween(range) {
        const height = this.getHeight();
        return (typeof height == "undefined" || (height >= range[0] && height <= range[1]));
    }
    isFrameRateBetween(range) {
        const frameRate = this.getFrameRate();
        return (typeof frameRate == "undefined" ||
            (frameRate >= range[0] && frameRate <= range[1]));
    }
    isBandwidthBetween(range) {
        const bandwidth = this.getBandwidth() || this.getAverageBandwidth();
        return (typeof bandwidth == "undefined" ||
            (bandwidth >= range[0] && bandwidth <= range[1]));
    }
    toString() {
        let out = "";
        out += this.streamInfo.toString();
        if (this.variant.isIFrameOnly) {
            return out;
        }
        if (this.playlist.hasDynamicChunklists()) {
            const props = JSON.parse(JSON.stringify(this.playlist.getDynamicChunklistProperties()));
            props.uri = this.variant.uri;
            props.baseUrl = this.playlist.getBaseUrl();
            out +=
                playlist_1.Playlist.buildUrl(this.playlist.getDynamicChunklistEndpoint(), props) +
                    "\n";
        }
        else {
            out +=
                playlist_1.Playlist.buildUrl(this.playlist.getBaseUrl() + this.variant.uri, this.playlist.getQueryStringParams()) + "\n";
        }
        return out;
    }
}
exports.Rendition = Rendition;
