"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const audio_track_1 = require("./audio-track");
class StreamInfo {
    constructor(playlist, variant) {
        this.playlist = playlist;
        this.variant = variant;
    }
    getTracks() {
        const me = this;
        let out = [];
        this.variant.audio.forEach((track) => {
            out.push(new audio_track_1.AudioTrack(me.playlist, track));
        });
        return out;
    }
    isIframeOnly() {
        return this.variant.isIFrameOnly || false;
    }
    hasAudio() {
        let has = false;
        if (/(mp4a|aac)/i.test(this.variant.codecs || "")) {
            has = true;
        }
        return has;
    }
    hasVideo() {
        let has = false;
        if (/(avc1|hevc)/i.test(this.variant.codecs || "")) {
            has = true;
        }
        return has;
    }
    propertiesToCommaSeparated(properties) {
        let out = "";
        for (let i = 0; i < properties.length; i++) {
            if (i > 0) {
                out += ",";
            }
            out += properties[i].join("=");
        }
        return out;
    }
    toString() {
        let out = "";
        let properties = [];
        if (this.variant.bandwidth) {
            properties.push(["BANDWIDTH", this.variant.bandwidth]);
        }
        if (this.variant.resolution) {
            properties.push([
                "RESOLUTION",
                this.variant.resolution.width + "x" + this.variant.resolution.height,
            ]);
        }
        if (this.variant.codecs) {
            properties.push(["CODECS", '"' + this.variant.codecs + '"']);
        }
        if (this.variant.averageBandwidth) {
            properties.push(["AVERAGE-BANDWIDTH", this.variant.averageBandwidth]);
        }
        if (this.variant.frameRate) {
            properties.push(["FRAME-RATE", this.variant.frameRate]);
        }
        if (this.variant.hdcpLevel) {
            properties.push(["HDCP-LEVEL", this.variant.hdcpLevel]);
        }
        if (this.variant.isIFrameOnly && this.playlist.includeVideo()) {
            if (this.variant.uri) {
                properties.push([
                    "URI",
                    '"' + this.playlist.getBaseUrl() + this.variant.uri + '"',
                ]);
            }
            out +=
                "#EXT-X-I-FRAME-STREAM-INF:" +
                    this.propertiesToCommaSeparated(properties) +
                    "\n";
        }
        else {
            if (this.variant.audio.length && this.playlist.includeAudio()) {
                properties.push(["AUDIO", '"' + this.variant.audio[0].groupId + '"']);
            }
            if (this.variant.closedCaptions.length) {
                properties.push([
                    "CLOSED-CAPTIONS",
                    '"' + this.variant.closedCaptions[0].groupId + '"',
                ]);
            }
            if (this.variant.subtitles.length) {
                properties.push([
                    "SUBTITLES",
                    '"' + this.variant.subtitles[0].groupId + '"',
                ]);
            }
            if (this.variant.video.length && this.playlist.includeVideo()) {
                properties.push(["VIDEO", '"' + this.variant.video[0].groupId + '"']);
            }
            out +=
                "#EXT-X-STREAM-INF:" +
                    this.propertiesToCommaSeparated(properties) +
                    "\n";
        }
        return out;
    }
}
exports.StreamInfo = StreamInfo;
